/**
 * Script loader plugin class.
 */
export default class ScriptLoaderPlugin {
    /** @type {import('@ima/core').Dependencies} */
    static get $dependencies(): import("@ima/core").Dependencies<any>;
    /**
     * Initializes the script loader.
     *
     * @param {import('@ima/core').Window} window
     * @param {import('@ima/core').Dispatcher} dispatcher
     * @param {ResourceLoader} resourceLoader
     */
    constructor(window: import('@ima/core').Window, dispatcher: import('@ima/core').Dispatcher, resourceLoader: ResourceLoader);
    /**
     * IMA.js Window
     *
     * @type {import('@ima/core').Window}
     */
    _window: import('@ima/core').Window;
    /**
     * IMA.js Dispatcher
     *
     * @type {import('@ima/core').Dispatcher}
     */
    _dispatcher: import('@ima/core').Dispatcher;
    /**
     * General-purpose utility for loading resources.
     *
     * @type {ResourceLoader}
     */
    _resourceLoader: ResourceLoader;
    /**
     * Object of loaded scripts.
     *
     * @type {Object<string, Promise<{url: string}>>}
     */
    _loadedScripts: {
        [x: string]: Promise<{
            url: string;
        }>;
    };
    /**
     * Load third party script to page.
     *
     * @param {string} url
     * @param {string=} [template]
     * @param {boolean} force
     * @returns {Promise<{url: string}>}
     */
    load(url: string, template?: string | undefined, force?: boolean): Promise<{
        url: string;
    }>;
    /**
     * Creates a new script element and returns it.
     *
     * @returns {HTMLScriptElement} The created script element.
     */
    _createScriptElement(): HTMLScriptElement;
    /**
     * Handle on load event for script. Resolve load promise and fire LOADED
     * events.
     *
     * @param {string} url
     * @returns {{url: string}}
     */
    _handleOnLoad(url: string): {
        url: string;
    };
    /**
     * Handle on error event for script. Reject load promise and fire LOADED
     * events.
     *
     * @param {string} url
     * @throws Error
     */
    _handleOnError(url: string): void;
}
import { ResourceLoader } from '@ima/plugin-resource-loader';
